==> digikam-2.4.1.tar.bz2: digikam-2.4.1/extra/kipi-plugins/expoblending/plugin/plugin_expoblending.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2009-12-13
 * Description : a tool to blend bracketed images.
 *
 * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef PLUGIN_EXPOBLENDING_H
#define PLUGIN_EXPOBLENDING_H

// Qt includes

#include <QVariant>
#include <QPointer>

// LibKIPI includes

#include <libkipi/plugin.h>

class QWidget;

class KAction;

namespace KIPIExpoBlendingPlugin
{
class Manager;
}

namespace KIPI
{
    class Interface;
}

class Plugin_ExpoBlending : public KIPI::Plugin
{
    Q_OBJECT

public:

    Plugin_ExpoBlending(QObject* parent, const QVariantList& args);
    virtual ~Plugin_ExpoBlending();

    KIPI::Category category( KAction* action ) const;
    void setup( QWidget* );

public Q_SLOTS:

    void slotActivate();

private:

    QWidget*                         m_parentWidget;

    KAction*                         m_action;

    KIPIExpoBlendingPlugin::Manager* m_manager;

    KIPI::Interface*                 m_interface;
};

#endif /* PLUGIN_EXPOBLENDING_H */

==> digikam_2.8.0.orig.tar.bz2: digikam-2.8.0/extra/kipi-plugins/expoblending/plugin/plugin_expoblending.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.digikam.org
 *
 * Date        : 2009-12-13
 * Description : a tool to blend bracketed images.
 *
 * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef PLUGIN_EXPOBLENDING_H
#define PLUGIN_EXPOBLENDING_H

// Qt includes

#include <QVariant>

// LibKIPI includes

#include <libkipi/plugin.h>

class QWidget;

class KAction;

namespace KIPI
{
    class Interface;
}

using namespace KIPI;

namespace KIPIExpoBlendingPlugin
{

class Manager;

class Plugin_ExpoBlending : public Plugin
{
    Q_OBJECT

public:

    Plugin_ExpoBlending(QObject* const parent, const QVariantList& args);
    virtual ~Plugin_ExpoBlending();

    Category category(KAction* action) const;
    void setup(QWidget*);

public Q_SLOTS:

    void slotActivate();

private:

    QWidget*   m_parentWidget;

    KAction*   m_action;

    Manager*   m_manager;

    Interface* m_interface;
};

} // namespace KIPIExpoBlendingPlugin

#endif /* PLUGIN_EXPOBLENDING_H */
